Installation eines benutzerdefinierten Steckverbinders

Nachdem Sie Ihren benutzerdefinierten Connector kompiliert und verpackt haben, müssen Sie ihn in Ihrer Discovery-Instanz installieren.

IBM Cloud Pak for Data IBM Software Hub

Diese Informationen gelten nur für installierte Bereitstellungen.

Discovery stellt ein Script mit dem Namen manage_custom_crawler.sh für die Installation und Deinstallation angepasster Connectors bereit. Das Script befindet sich im Verzeichnis scripts der entpackten Datei custom-crawler-docs.zip, die im Abschnitt Informationen zur Datei custom-crawler-docs.zip beschrieben ist.

Connector installieren

Sie können Ihren angepassten Connector in Ihrer Instanz von Discovery installieren, indem Sie die folgenden Schritte ausführen.

  1. Stellen Sie sicher, dass Sie alle Schritte zum Erstellen eines angepassten Connectors bis einschließlich der Schritte ausgeführt haben, die unter Beispielconnector kompilieren und packen aufgeführt sind.

  2. Führen Sie in dem Verzeichnis Ihrer lokalen Maschine, in dem Sie Ihren angepassten Connector erstellt und kompiliert haben, den folgenden Befehl aus:

    bash scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {access token} deploy -n {crawler name} -f {built_connector_zip_file}
    

    wo Sie Werte für die folgenden Variablen angeben:

    • endpunkt: URL für Ihre Service-Instanz. Sie können diesen Wert im Abschnitt "Zugriffsinformationen" auf der Übersichtsseite der Service-Instanz in der Verwaltungskonsole IBM Cloud Pak for Data abrufen.
    • Zugriffstoken: Bearer-Token, der für den Zugriff auf den Endpunkt erforderlich ist. Sie können diesen Wert auf der gleichen Seite wie den Endpunkt abrufen.
    • crawler name: (Optional) Name, den Sie für den Crawler angegeben haben.
    • {built_connector_zip_file} ist der Name der Datei, die Sie beim Kompilieren und Verpacken des Beispiel-Connectors erstellt haben.

    Beispiel:

    bash scripts/manage_custom_crawler.sh --endpoint https://mycpd.wd40.example.com/discovery/zen40-wd/instances/1638165624521059/api --token eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6ImVKcV9HY29NcHF5WUFJcVByZ0x0cERRZDNQcmRiTWo5TGg0X09WOEU4MlkifP.eyJ1aXQiOiIxMDAwMzMwOTk5IiwidXNlcm5hbWUiOiJhZG1pbiIsInJvbGUiOiJBZG1pbiIsInBlcm1pc3Npb25zIjpbImFkbWluaXN0cmF0b3IiLCJjYW5fcHJvdmlzaW9uIl0sImdyb3VwcyI6WzEwMDAwXSwic3ViIjoiYWRtaW4iLCJpc3MiOiJLTk9YU1NPIiwiYXVkIjoiRFNYIiwiaWF0IjoxNjQyNzAyMDA3fQ.5oymGw7pi6tAbTMW9rcdb62G95teR2-tKyznA_wjk_G698fbx1Zl73KZKyEWcTKtyX7IJ1Px5DPdophcqS9i3bPJowHy-ioVp6DML02mscZImhvZPra-e6gwUdhSB64KArmMClo1-kZG20EclNh6-oxR447Bjdsgp7IYpkmynmw0K6vPIqmzwEhr9gAK1vWLOoVd4EoiYNuxZaSFL5byJ0mnQxXzM14w3lKQHZ91WYVKc4JnuJiSVsdpGqVz1JNFmT8D9FBqJQ4uxtshnii0f1Yh-USKCbJmMPXicU8cDtJIfheBejwenfvejUTz5rgZgymYWrGvw3G2oOx_L1Yg-Q deploy -n awesome_crawler -f awesome_crawler.zip
    

    Anstatt ein Zugriffstoken für die Authentifizierung anzugeben, können Sie auch Parameter für den Benutzernamen und das Passwort angeben. Weitere Informationen finden Sie unter Verständnis des manage_custom_crawler.sh Skripts.

Wenn der benutzerdefinierte Crawler bereitgestellt wird, wird dem Connector eine Ressourcen-ID zugewiesen.

Installierten Connector überprüfen

Überprüfen Sie, ob der Konnektor in der Discovery-Instanz bereitgestellt wurde, indem Sie sich beim Discovery-Tooling anmelden und sicherstellen, dass Ihr Konnektor als Option auf der Seite Sammlung konfigurieren angezeigt wird.

Installierten Connector in Discovery verwenden

Führen Sie die unter Sammlung erstellen aufgelisteten Schritte aus, um den installierten angepassten Connector zu verwenden. Der angepasste Connector wird in der Connectorliste unter Cloud Pak for Data-Datenquellen konfigurieren angezeigt. Weitere Informationen finden Sie unter Verwendung eines benutzerdefinierten Konnektors mit dem Discovery Tooling.

Connector deinstallieren

Um einen benutzerdefinierten Connector von einer Discovery-Instanz zu deinstallieren, führen Sie die folgenden Schritte aus:

  1. Optional: Wenn Sie die Ressourcen-ID nicht kennen, führen Sie den folgenden Befehl aus, um die benutzerdefinierten Anschlüsse aufzulisten. Die Ressourcen-IDs der Konnektoren werden zurückgegeben.

    scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {token} list
    
  2. Führen Sie den folgenden Befehl in dem Verzeichnis aus, in das Sie die ZIP-Datei des benutzerdefinierten Connectors extrahiert haben, um den Connector zu deinstallieren:

    scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {token} undeploy --id {crawler_resource_id}
    

    wobei {crawler-resource-id} die ID ist, die für den Crawler erzeugt wird, wenn er eingesetzt wird.

    scripts/manage_custom_crawler.sh --endpoint {endpoint} --token {token} undeploy --id {crawler_resource_id}
    

Anstatt ein Zugriffstoken für die Authentifizierung anzugeben, können Sie auch Parameter für den Benutzernamen und das Passwort angeben. Weitere Informationen finden Sie unter Verständnis des manage_custom_crawler.sh Skripts.

Informationen zum Script manage_custom_crawler.sh

Im Script manage_custom_crawler.sh gibt es die folgende interne Dokumentation:

Watson Discovery Custom Crawler Manager

This script will help you deploy, manage, and undeploy your custom crawler for
Watson Discovery.

Subcommands:
  deploy        Add a new Custom Crawler to your Watson Discovery instance.
  undeploy      Undeploy your Custom Crawler by name.
  list          List all Custom Crawlers for your Watson Discovery instance.

Options:
  -e --endpoint         The endpoint URL for your cluster and add-on service instance
                        (`https://{cpd_cluster_host}:{port}/discovery/{release}/instances/{instance_id}/api`)
  -t --token            The authorization token of your Cloud Pak instance
  -u --user             The user name of your Cloud Pak instance
  -p --password         The user password of your Cloud Pak instance
                        If the password is not specified, the command line prompts to input
  -n --name             The name of the custom crawler to upload (deploy only)
  -f --file             The path of the custom crawler package to upload (deploy only)
  -i --id               The crawler_resource_id value to delete the custom crawler (undeploy only)
  --help                Show this message.

Nur 4.0.5 und frühere Versionen

Installieren eines Verbinders in 4.0.5 und früheren Versionen

Sie können Ihren angepassten Connector in Ihrer Instanz von Discovery installieren, indem Sie die folgenden Schritte ausführen.

  1. Stellen Sie sicher, dass Sie alle Schritte zum Erstellen eines angepassten Connectors bis einschließlich der Schritte ausgeführt haben, die unter Beispielconnector kompilieren und packen aufgeführt sind.

  2. Führen Sie in dem Verzeichnis Ihrer lokalen Maschine, in dem Sie Ihren angepassten Connector erstellt und kompiliert haben, den folgenden Befehl aus:

    bash scripts/manage_custom_crawler.sh deploy -z {built_connector_zip_file}
    

    Hier steht {built_connector_zip_file} für den Namen der Datei, die Sie beim Durcharbeiten des Abschnitts Beispielconnector kompilieren und packen erstellt haben.

    Wenn Ihre Discovery-Instanz auf Red Hat OpenShift ausgeführt wird, geben Sie den Parameter -o oder --openshift mit dem Skript an.

    Beispiel:

    bash scripts/manage_custom_crawler.sh deploy -z myCrawler.zip -o true
    

Deinstallation eines Connectors in 4.0.5 und früheren Versionen

Führen Sie zum Deinstallieren eines angepassten Connectors für eine Instanz von Discovery den folgenden Befehl im Stammverzeichnis der entpackten Datei custom-crawler-docs.zip aus:

bash scripts/manage_custom_crawler.sh undeploy -n {built_connector_name}

Hier steht {build_connector_name} für den Namen des installierten Connectors (nicht der ZIP-Datei).

Wenn Ihre IBM Watson® Discovery-Instanz auf Red Hat OpenShift ausgeführt wird, geben Sie den Parameter -o oder --openshift mit dem Skript an.

bash scripts/manage_custom_crawler.sh undeploy -n {built_connector_name} -o true

Verstehen des manage_custom_crawler.sh-Skripts in 4.0.5 und früheren Versionen

Im Script manage_custom_crawler.sh gibt es die folgende interne Dokumentation:

Usage: ${BASH_SOURCE[0]} [--pathToZip PATH] [--properties PROPERTIES] [--xml XML]

Watson Discovery Custom Crawler Manager

This script will help you deploy, manage, and undeploy your custom crawler for
Watson Discovery.

Subcommands:
  deploy        Add a new Custom Crawler to your Watson Discovery instance.
  properties    Generate the properties file for your crawler.
  undeploy      Undeploy your Custom Crawler by name.
  list          List all Custom Crawlers for your Watson Discovery instance.

Options:
  -d --discovery        The name of the Watson Discovery instance
  -z --zipfile          The path to the zip file to be uploaded.
                        For deploy only.
  -x --xml              The path to the XML file to be uploaded.
                        For deploy only.
  -n --name             The name of the Custom Crawler to undeploy.
  -m --messages         The path to the properties file, used when doing a two part deploy.
                        For properties only.
  -o --openshift        Set flag to true if this is an OpenShift Cluster
  --help                Show this message.